@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2009 The Trustees of Indiana University.
+ * Copyright (c) 2004-2010 The Trustees of Indiana University.
  *                         All rights reserved.
  * Copyright (c) 2004-2005 The Trustees of the University of Tennessee.
  *                         All rights reserved.
@@ -674,6 +674,9 @@ static int self_cold_start(opal_crs_self_snapshot_t *snapshot) {
      */
     if( OPAL_SUCCESS != (ret = opal_crs_base_extract_expected_component(snapshot->super.local_location, 
                                                                         &component_name, &prev_pid) ) ) {
+        opal_output(mca_crs_self_component.super.output_handle,
+                    "crs:self: self_cold_start: Error: Failed to extract the metadata from the local snapshot (%s). Returned %d.",
+                    snapshot->super.local_location, ret);
         exit_status = ret;
         goto cleanup;
     }
@@ -695,6 +698,13 @@ static int self_cold_start(opal_crs_self_snapshot_t *snapshot) {
      * JJH: Command lines limited to 256 chars.
      */
     opal_crs_base_metadata_read_token(snapshot->super.local_location, CRS_METADATA_CONTEXT, &tmp_argv);
+    if( NULL == tmp_argv ) {
+        opal_output(mca_crs_self_component.super.output_handle,
+                    "crs:self: self_cold_start: Error: Failed to read the %s token from the local checkpoint in %s",
+                    CRS_METADATA_CONTEXT, snapshot->super.local_location);
+        exit_status = OPAL_ERROR;
+        goto cleanup;
+    }
     asprintf(&snapshot->cmd_line, "%s", tmp_argv[0]);
 
     /*
